@@ -43,7 +43,6 @@ export default class DING extends Extension {
         this.data.currentProcess = null;
         this.data.dbusTimeoutId = 0;
         this.data.switchWorkspaceId = 0;
-        this.data.enableCalled = false;
 
         this.data.GnomeShellOverride = null;
 
@@ -67,11 +66,6 @@ export default class DING extends Extension {
     }
 
     enable() {
-        if (this.data.enableCalled) {
-            return;
-        }
-        this.data.enableCalled = true;
-
         if (!this.data.GnomeShellOverride) {
             this.data.GnomeShellOverride = new GnomeShellOverride.GnomeShellOverride();
         }
@@ -92,11 +86,6 @@ export default class DING extends Extension {
     }
 
     disable() {
-        if (!this.data.enableCalled) {
-            return;
-        }
-        this.data.enableCalled = false;
-
         this.DesktopIconsUsableArea = null;
         this.data.isEnabled = false;
         this.killCurrentProcess();
@@ -329,6 +318,7 @@ export default class DING extends Extension {
     updateDesktopGeometry() {
         if (this.data.actionGroup && (Main.layoutManager.monitors.length != 0)) {
             this.data.actionGroup.change_action_state('desktopGeometry', this.getDesktopGeometry());
+            this.data.x11Manager.refreshWindowsPosition();
         }
     }
 
